@@ -45,12 +45,8 @@ pub fn build(stream: proc_macro::TokenStream) -> proc_macro::TokenStream {
     let build = parse_macro_input!(stream as BuildMacro);
     let tokens = RawString(build.into_tokens_string());
     let target_dir = std::env::var("PATH").expect("No `PATH` env variable set");
-
-    let target_dir = if let Some(end) = target_dir.find(';') {
-        RawString(target_dir[..end].to_string())
-    } else {
-        RawString("".to_string())
-    };
+    let end = target_dir.find(';').expect("Path not ending in `;`");
+    let target_dir = RawString(target_dir[..end].to_string());
 
     let tokens = quote! {
         {
@@ -63,8 +59,7 @@ pub fn build(stream: proc_macro::TokenStream) -> proc_macro::TokenStream {
             );
 
             path.push("windows.rs");
-            let mut file = ::std::fs::File::create(&path).expect("Failed to create windows.rs");
-            file.write_all(#tokens.as_bytes()).expect("Could not write generated code to output file");
+            ::std::fs::write(&path, #tokens).expect("Could not write generated code to windows.rs");
 
             let mut cmd = ::std::process::Command::new("rustfmt");
             cmd.arg(&path);
@@ -113,22 +108,23 @@ pub fn build(stream: proc_macro::TokenStream) -> proc_macro::TokenStream {
             let mut source : ::std::path::PathBuf = ::std::env::var("CARGO_MANIFEST_DIR").expect("No `CARGO_MANIFEST_DIR` env variable set").into();
             source.push(".windows");
 
-            println!("cargo:rerun-if-changed={}", source.to_str().expect("`CARGO_MANIFEST_DIR` not a valid path"));
+            if source.exists() {
+                println!("cargo:rerun-if-changed={}", source.to_str().expect("`CARGO_MANIFEST_DIR` not a valid path"));
 
-            // The `target_arch` cfg is not set for build scripts so we need to sniff it out from the environment variable.
-            source.push(match ::std::env::var("CARGO_CFG_TARGET_ARCH").expect("No `CARGO_CFG_TARGET_ARCH` env variable set").as_str() {
-                "x86_64" => "x64",
-                "x86" => "x86",
-                "arm" => "arm",
-                "aarch64" => "arm64",
-                unexpected => panic!("Unexpected `{}` architecture set by `CARGO_CFG_TARGET_ARCH`", unexpected),
-            });
+                // The `target_arch` cfg is not set for build scripts so we need to sniff it out from the environment variable.
+                source.push(match ::std::env::var("CARGO_CFG_TARGET_ARCH").expect("No `CARGO_CFG_TARGET_ARCH` env variable set").as_str() {
+                    "x86_64" => "x64",
+                    "x86" => "x86",
+                    "arm" => "arm",
+                    "aarch64" => "arm64",
+                    unexpected => panic!("Unexpected `{}` architecture set by `CARGO_CFG_TARGET_ARCH`", unexpected),
+                });
 
-            println!("cargo:rustc-link-search=native={}", source.to_str().expect("`CARGO_MANIFEST_DIR` not a valid path"));
+                if source.exists() {
+                    println!("cargo:rustc-link-search=native={}", source.to_str().expect("`CARGO_MANIFEST_DIR` not a valid path"));
+                }
 
-            let mut destination : ::std::path::PathBuf = #target_dir.into();
-
-            if destination.exists() {
+                let mut destination : ::std::path::PathBuf = #target_dir.into();
                 destination.pop();
                 destination.pop();
 
